#
# spec file for package python-betamax
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
Name:           python-betamax
Version:        0.9.0
Release:        1.3
Summary:        A VCR imitation for python-requests
License:        Apache-2.0
Group:          Development/Languages/Python
URL:            https://github.com/sigmavirus24/betamax
Source:         https://files.pythonhosted.org/packages/source/b/betamax/betamax-%{version}.tar.gz
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module wheel}
BuildRequires:  python-rpm-macros
Requires:       python-requests >= 2.0
BuildArch:      noarch
%python_subpackages

%description
Betamax is a VCR_ imitation for requests. This will make mocking out requests
much easier.

%prep
%setup -q -n betamax-%{version}

%build
%pyproject_wheel

%install
%pyproject_install

%files %{python_files}
%doc AUTHORS.rst README.rst
%license LICENSE
%{python_sitelib}/betamax
%{python_sitelib}/betamax-%{version}.dist-info

%changelog
* Sat Apr 20 2024 Dirk Müller <dmueller@suse.com>
- update to 0.9.0:
  * Add support for urllib3 2.0
  * Fix documentation
  * Add support for binary serializer storage; useful with custom
    serializers (such as pickle based), however all builtin
    betamax serializers remain text based.
  * Fix bug with new_episodes always trying to record.
  * Improved documentation.
  * This release drops support for Python 3.3; if you are still
    using Python 3.3 update your Python or don't update to
    betamax 0.8.2.
  * This release is the first release that declares support for
    Python 3.7, however previous versions most likely worked with
    3.7 as well.
* Fri Apr 21 2023 Dirk Müller <dmueller@suse.com>
- add sle15_python_module_pythons (jsc#PED-68)
* Thu Apr 13 2023 Matej Cepl <mcepl@suse.com>
- Make calling of %%{sle15modernpython} optional.
* Thu Dec 13 2018 Thomas Bechtold <tbechtold@suse.com>
- update to 0.8.1:
  - Previous attempts to sanitize cassette names were incomplete.
    Sanitization has become more thorough which could have some affects on
    existing cassette files. **This may cause new cassettes to be generated.**
  - Fix bug where there may be an exception raised in a
    ``betamax.exceptions.BetamaxError`` repr.
- Use %%license macro
* Tue May 16 2017 dmueller@suse.com
- convert to singlespec packaging
* Tue Nov 15 2016 dmueller@suse.com
- update to 0.8.0:
  - Add ``betamax_parametrized_recorder`` and ``betamax_parametrized_session``
    to our list of pytest fixtures so that users will have parametrized cassette
    names when writing parametrized tests with our fixtures. (I wonder if I can
    mention parametrization a bunch more times so I can say parametrize a lot in
    this bullet note.)
  - Add ``ValidationError`` and a set of subclasses for each possible validation
    error.
  - Raise ``InvalidOption`` on unknown cassette options rather than silently
    ignoring extra options.
  - Raise a subclass of ``ValidationError`` when a particular cassette option is
    invalid, rather than silently ignoring the validation failure.
  - Fix bug with query string matcher where query-strings without values (e.g.,
    ``?foo&bar`` as opposed to ``?foo=1&bar=2``) were treated as if there were
    no query string.
  - Fix issue #108 by effectively copying the items in the match_requests_on
    list into the match_options set on a Cassette instance
* Tue Jun  7 2016 tbechtold@suse.com
- update to 0.7.0:
  - Add before_record and before_playback hooks
  - Allow per-cassette placeholders to be merged and override global placeholders
  - Fix bug where the QueryMatcher failed matching on high Unicode points
  - Add betamax_recorder pytest fixture
  - Change default behaviour to allow duplicate interactions to be recorded
    in single cassette
  - Add allow_playback_repeats to allow an interaction to be used more than once
    from a single cassette
  - Always return a new Response object from an Interaction to allow for a
    streaming response to be usable multiple times
  - Remove CI support for Pythons 2.6 and 3.2
* Thu Feb 11 2016 tbechtold@suse.com
- Initial packaging (version 0.5.1)
